@@ -8,9 +8,9 @@ pub(crate) struct AssignmentResolver<'src: 'run, 'run> {
 
 impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
   pub(crate) fn resolve_assignments(
-    assignments: &Table<'src, Assignment<'src>>,
-  ) -> CompileResult<'src, ()> {
-    let mut resolver = AssignmentResolver {
+    assignments: &'run Table<'src, Assignment<'src>>,
+  ) -> CompileResult<'src> {
+    let mut resolver = Self {
       stack: Vec::new(),
       evaluated: BTreeSet::new(),
       assignments,
@@ -23,7 +23,7 @@ impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
     Ok(())
   }
 
-  fn resolve_assignment(&mut self, name: &'src str) -> CompileResult<'src, ()> {
+  fn resolve_assignment(&mut self, name: &'src str) -> CompileResult<'src> {
     if self.evaluated.contains(name) {
       return Ok(());
     }
@@ -52,23 +52,26 @@ impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
     Ok(())
   }
 
-  fn resolve_expression(&mut self, expression: &Expression<'src>) -> CompileResult<'src, ()> {
+  fn resolve_expression(&mut self, expression: &Expression<'src>) -> CompileResult<'src> {
     match expression {
       Expression::Variable { name } => {
         let variable = name.lexeme();
         if self.evaluated.contains(variable) {
           Ok(())
         } else if self.stack.contains(&variable) {
-          let token = self.assignments[variable].name.token();
           self.stack.push(variable);
-          Err(token.error(CircularVariableDependency {
-            variable,
-            circle: self.stack.clone(),
-          }))
+          Err(
+            self.assignments[variable]
+              .name
+              .error(CircularVariableDependency {
+                variable,
+                circle: self.stack.clone(),
+              }),
+          )
         } else if self.assignments.contains_key(variable) {
           self.resolve_assignment(variable)
         } else {
-          Err(name.token().error(UndefinedVariable { variable }))
+          Err(name.token.error(UndefinedVariable { variable }))
         }
       }
       Expression::Call { thunk } => match thunk {
