@@ -13,24 +13,31 @@ impl Compiler {
     let mut srcs: HashMap<PathBuf, &str> = HashMap::new();
     let mut loaded = Vec::new();
 
-    let mut stack: Vec<(PathBuf, u32)> = Vec::new();
-    stack.push((root.into(), 0));
+    let mut stack = Vec::new();
+    stack.push(Source::root(root));
 
-    while let Some((current, depth)) = stack.pop() {
-      let (relative, src) = loader.load(root, &current)?;
+    while let Some(current) = stack.pop() {
+      let (relative, src) = loader.load(root, &current.path)?;
       loaded.push(relative.into());
       let tokens = Lexer::lex(relative, src)?;
-      let mut ast = Parser::parse(depth, &current, &tokens)?;
+      let mut ast = Parser::parse(
+        &current.path,
+        &current.namepath,
+        current.depth,
+        &tokens,
+        &current.working_directory,
+      )?;
 
-      paths.insert(current.clone(), relative.into());
-      srcs.insert(current.clone(), src);
+      paths.insert(current.path.clone(), relative.into());
+      srcs.insert(current.path.clone(), src);
 
       for item in &mut ast.items {
         match item {
-          Item::Mod {
-            name,
+          Item::Module {
             absolute,
-            path,
+            name,
+            optional,
+            relative,
           } => {
             if !unstable {
               return Err(Error::Unstable {
@@ -38,37 +45,64 @@ impl Compiler {
               });
             }
 
-            let parent = current.parent().unwrap();
+            let parent = current.path.parent().unwrap();
 
-            let import = if let Some(path) = path {
-              parent.join(Self::expand_tilde(&path.cooked)?)
+            let import = if let Some(relative) = relative {
+              let path = parent.join(Self::expand_tilde(&relative.cooked)?);
+
+              if path.is_file() {
+                Some(path)
+              } else {
+                None
+              }
             } else {
               Self::find_module_file(parent, *name)?
             };
 
-            if srcs.contains_key(&import) {
-              return Err(Error::CircularImport { current, import });
+            if let Some(import) = import {
+              if srcs.contains_key(&import) {
+                return Err(Error::CircularImport {
+                  current: current.path,
+                  import,
+                });
+              }
+              *absolute = Some(import.clone());
+              stack.push(current.module(*name, import));
+            } else if !*optional {
+              return Err(Error::MissingModuleFile { module: *name });
             }
-            *absolute = Some(import.clone());
-            stack.push((import, depth + 1));
           }
-          Item::Import { relative, absolute } => {
+          Item::Import {
+            relative,
+            absolute,
+            optional,
+            path,
+          } => {
             let import = current
+              .path
               .parent()
               .unwrap()
               .join(Self::expand_tilde(&relative.cooked)?)
               .lexiclean();
-            if srcs.contains_key(&import) {
-              return Err(Error::CircularImport { current, import });
+
+            if import.is_file() {
+              if srcs.contains_key(&import) {
+                return Err(Error::CircularImport {
+                  current: current.path,
+                  import,
+                });
+              }
+              *absolute = Some(import.clone());
+              stack.push(current.import(import));
+            } else if !*optional {
+              return Err(Error::MissingImportFile { path: *path });
             }
-            *absolute = Some(import.clone());
-            stack.push((import, depth + 1));
           }
           _ => {}
         }
       }
 
-      asts.insert(current.clone(), ast.clone());
+      asts.insert(current.path, ast.clone());
     }
 
     let justfile = Analyzer::analyze(&loaded, &paths, &asts, root)?;
@@ -81,7 +115,7 @@ impl Compiler {
     })
   }
 
-  fn find_module_file<'src>(parent: &Path, module: Name<'src>) -> RunResult<'src, PathBuf> {
+  fn find_module_file<'src>(parent: &Path, module: Name<'src>) -> RunResult<'src, Option<PathBuf>> {
     let mut candidates = vec![format!("{module}.just"), format!("{module}/mod.just")]
       .into_iter()
       .filter(|path| parent.join(path).is_file())
@@ -112,8 +146,8 @@ impl Compiler {
     }
 
     match candidates.as_slice() {
-      [] => Err(Error::MissingModuleFile { module }),
-      [file] => Ok(parent.join(file).lexiclean()),
+      [] => Ok(None),
+      [file] => Ok(Some(parent.join(file).lexiclean())),
       found => Err(Error::AmbiguousModuleFile {
         found: found.into(),
         module,
@@ -134,7 +168,13 @@ impl Compiler {
   #[cfg(test)]
   pub(crate) fn test_compile(src: &str) -> CompileResult<Justfile> {
     let tokens = Lexer::test_lex(src)?;
-    let ast = Parser::parse(0, &PathBuf::new(), &tokens)?;
+    let ast = Parser::parse(
+      &PathBuf::new(),
+      &Namepath::default(),
+      0,
+      &tokens,
+      &PathBuf::new(),
+    )?;
     let root = PathBuf::from("justfile");
     let mut asts: HashMap<PathBuf, Ast> = HashMap::new();
     asts.insert(root.clone(), ast);
