@@ -18,7 +18,6 @@ pub(crate) fn chooser_default(justfile: &Path) -> OsString {
 }
 
 #[derive(Debug, PartialEq)]
-#[allow(clippy::struct_excessive_bools)]
 pub(crate) struct Config {
   pub(crate) check: bool,
   pub(crate) color: Color,
@@ -32,6 +31,7 @@ pub(crate) struct Config {
   pub(crate) list_heading: String,
   pub(crate) list_prefix: String,
   pub(crate) load_dotenv: bool,
+  pub(crate) no_dependencies: bool,
   pub(crate) search_config: SearchConfig,
   pub(crate) shell: Option<String>,
   pub(crate) shell_args: Option<Vec<String>>,
@@ -103,6 +103,7 @@ mod arg {
   pub(crate) const JUSTFILE: &str = "JUSTFILE";
   pub(crate) const LIST_HEADING: &str = "LIST-HEADING";
   pub(crate) const LIST_PREFIX: &str = "LIST-PREFIX";
+  pub(crate) const NO_DEPS: &str = "NO-DEPS";
   pub(crate) const NO_DOTENV: &str = "NO-DOTENV";
   pub(crate) const NO_HIGHLIGHT: &str = "NO-HIGHLIGHT";
   pub(crate) const QUIET: &str = "QUIET";
@@ -214,6 +215,12 @@ impl Config {
           .value_name("TEXT")
           .takes_value(true),
       )
+      .arg (
+        Arg::with_name(arg::NO_DEPS)
+          .long("no-deps")
+          .alias("no-dependencies")
+          .help("Don't run recipe dependencies")
+      )
       .arg(
         Arg::with_name(arg::NO_DOTENV)
           .long("no-dotenv")
@@ -346,11 +353,13 @@ impl Config {
       .arg(
         Arg::with_name(cmd::FORMAT)
           .long("fmt")
+          .alias("format")
           .help("Format and overwrite justfile"),
       )
       .arg(
         Arg::with_name(cmd::INIT)
           .long("init")
+          .alias("initialize")
           .help("Initialize new justfile in project root"),
       )
       .arg(
@@ -649,6 +658,7 @@ impl Config {
         .unwrap_or("    ")
         .to_owned(),
       load_dotenv: !matches.is_present(arg::NO_DOTENV),
+      no_dependencies: matches.is_present(arg::NO_DEPS),
       search_config,
       shell: matches.value_of(arg::SHELL).map(str::to_owned),
       shell_args,
@@ -694,6 +704,7 @@ mod tests {
       $(dry_run: $dry_run:expr,)?
       $(dump_format: $dump_format:expr,)?
       $(highlight: $highlight:expr,)?
+      $(no_dependencies: $no_dependencies:expr,)?
       $(search_config: $search_config:expr,)?
       $(shell: $shell:expr,)?
       $(shell_args: $shell_args:expr,)?
@@ -713,6 +724,7 @@ mod tests {
           $(dry_run: $dry_run,)?
           $(dump_format: $dump_format,)?
           $(highlight: $highlight,)?
+          $(no_dependencies: $no_dependencies,)?
           $(search_config: $search_config,)?
           $(shell: $shell,)?
           $(shell_args: $shell_args,)?
@@ -888,6 +900,18 @@ mod tests {
     highlight: false,
   }
 
+  test! {
+    name: no_deps,
+    args: ["--no-deps"],
+    no_dependencies: true,
+  }
+
+  test! {
+    name: no_dependencies,
+    args: ["--no-dependencies"],
+    no_dependencies: true,
+  }
+
   test! {
     name: unsorted_default,
     args: [],
@@ -1427,6 +1451,16 @@ mod tests {
     },
   }
 
+  error! {
+    name: fmt_alias,
+    args: ["--format", "bar"],
+    error: ConfigError::SubcommandArguments { subcommand, arguments },
+    check: {
+      assert_eq!(subcommand, cmd::FORMAT);
+      assert_eq!(arguments, &["bar"]);
+    },
+  }
+
   error! {
     name: init_arguments,
     args: ["--init", "bar"],
@@ -1437,6 +1471,16 @@ mod tests {
     },
   }
 
+  error! {
+    name: init_alias,
+    args: ["--initialize", "bar"],
+    error: ConfigError::SubcommandArguments { subcommand, arguments },
+    check: {
+      assert_eq!(subcommand, cmd::INIT);
+      assert_eq!(arguments, &["bar"]);
+    },
+  }
+
   error! {
     name: show_arguments,
     args: ["--show", "foo", "bar"],
