@@ -14,13 +14,16 @@ pub(crate) enum Keyword {
   False,
   If,
   IgnoreComments,
+  Import,
+  Mod,
   PositionalArguments,
+  Quiet,
   Set,
   Shell,
+  Tempdir,
   True,
   WindowsPowershell,
   WindowsShell,
-  Tempdir,
 }
 
 impl Keyword {
