@@ -21,8 +21,37 @@ impl<'src> Node<'src> for Item<'src> {
       Item::Alias(alias) => alias.tree(),
       Item::Assignment(assignment) => assignment.tree(),
       Item::Comment(comment) => comment.tree(),
-      Item::Import { relative, .. } => Tree::atom("import").push(format!("{relative}")),
-      Item::Mod { name, .. } => Tree::atom("mod").push(name.lexeme()),
+      Item::Import {
+        relative, optional, ..
+      } => {
+        let mut tree = Tree::atom("import");
+
+        if *optional {
+          tree = tree.push("?");
+        }
+
+        tree.push(format!("{relative}"))
+      }
+      Item::Module {
+        name,
+        optional,
+        relative,
+        ..
+      } => {
+        let mut tree = Tree::atom("mod");
+
+        if *optional {
+          tree = tree.push("?");
+        }
+
+        tree = tree.push(name.lexeme());
+
+        if let Some(relative) = relative {
+          tree = tree.push(format!("{relative}"));
+        }
+
+        tree
+      }
       Item::Recipe(recipe) => recipe.tree(),
       Item::Set(set) => set.tree(),
     }
@@ -240,6 +269,7 @@ impl<'src> Node<'src> for Set<'src> {
       | Setting::Export(value)
       | Setting::Fallback(value)
       | Setting::PositionalArguments(value)
+      | Setting::Quiet(value)
       | Setting::WindowsPowerShell(value)
       | Setting::IgnoreComments(value) => {
         set.push_mut(value.to_string());
