@@ -6,7 +6,6 @@ pub(crate) const WINDOWS_POWERSHELL_SHELL: &str = "powershell.exe";
 pub(crate) const WINDOWS_POWERSHELL_ARGS: &[&str] = &["-NoLogo", "-Command"];
 
 #[derive(Debug, PartialEq, Serialize, Default)]
-#[allow(clippy::struct_excessive_bools)]
 pub(crate) struct Settings<'src> {
   pub(crate) allow_duplicate_recipes: bool,
   pub(crate) dotenv_filename: Option<String>,
@@ -16,6 +15,7 @@ pub(crate) struct Settings<'src> {
   pub(crate) fallback: bool,
   pub(crate) ignore_comments: bool,
   pub(crate) positional_arguments: bool,
+  pub(crate) quiet: bool,
   pub(crate) shell: Option<Shell<'src>>,
   pub(crate) tempdir: Option<String>,
   pub(crate) windows_powershell: bool,
@@ -52,6 +52,9 @@ impl<'src> Settings<'src> {
         Setting::PositionalArguments(positional_arguments) => {
           settings.positional_arguments = positional_arguments;
         }
+        Setting::Quiet(quiet) => {
+          settings.quiet = quiet;
+        }
         Setting::Shell(shell) => {
           settings.shell = Some(shell);
         }
