@@ -98,11 +98,18 @@ fn unstable_passed() {
     panic!("justfile failed with status: {}", output.status);
   }
 
-  assert_eq!(fs::read_to_string(&justfile).unwrap(), "x := 'hello'\n",);
+  assert_eq!(fs::read_to_string(&justfile).unwrap(), "x := 'hello'\n");
 }
 
 #[test]
 fn write_error() {
+  // skip this test if running as root, since root can write files even if
+  // permissions would otherwise forbid it
+  #[cfg(not(windows))]
+  if unsafe { libc::getuid() } == 0 {
+    return;
+  }
+
   let tempdir = temptree! {
     justfile: "x    :=    'hello'   ",
   };
