@@ -44,6 +44,7 @@ mod completions;
 mod conditional;
 mod confirm;
 mod delimiters;
+mod directories;
 mod dotenv;
 mod edit;
 mod equals;
@@ -67,6 +68,7 @@ mod modules;
 mod multibyte_char;
 mod newline_escape;
 mod no_cd;
+mod no_dependencies;
 mod no_exit_message;
 mod os_attributes;
 mod parser;
@@ -87,6 +89,7 @@ mod show;
 mod slash_operator;
 mod string;
 mod subsequents;
+mod summary;
 mod tempdir;
 mod undefined_variables;
 mod unstable;
